import pandas as pd

from marcuslion.restcontroller import RestController
from marcuslion.config import IS_BACKEND_PARAM


class MlDatasets(RestController):
    """
    MarcusLion User dataset class
    """

    def __init__(self):
        super().__init__("/ml-datasets")

    def upload(self, file_path, category=None, title=None, description=None) -> any:
        """
        Datasets.upload(file_path, name, description, tags)
        """
        print(f"Uploading ...")
        return super().upload_file("", file_path, {
            "category": category,
            "title": title,
            "description": description,
            IS_BACKEND_PARAM: True
        })

    def list(self, params=None) -> pd.DataFrame:
        """
        Datasets.list()
        """
        if params is None:
            params = {}
        params[IS_BACKEND_PARAM] = True
        data = super().verify_get("", params)
        if data is None:
            return pd.DataFrame()
        return pd.DataFrame(data)

    def download(self, dataset_id, output_path=None) -> any:
        """
        Datasets.download(ref)
        """
        print(f"Downloading ...")
        return super().download_file("/download/" + dataset_id, {
            IS_BACKEND_PARAM: True
        }, output_path)



from marcuslion.restcontroller import RestController
from marcuslion.config import IS_BACKEND_PARAM


class Resume(RestController):
    def __init__(self):
        super().__init__("/resume")

    def upload(self, file_path) -> any:
        return super().upload_file("/upload", file_path, {
            IS_BACKEND_PARAM: True
        })



import os

"""
MarcusLion Global variable
"""
global __env__
global __base_url__
global __api_key__
global __api_version__
global __project_id__
global __backend_base_url__
global __backend_api_version__

IS_BACKEND_PARAM = 'is_backend'


def __init__():
    global __base_url__
    global __backend_base_url__
    global __backend_api_version__
    global __env__
    global __api_key__
    global __api_version__
    global __project_id__

    __env__ = os.getenv('MARCUSLION_ENV', "uat")
    __api_key__ = os.getenv('MARCUSLION_API_KEY', "b7f88c9c-94ba-11ee-b9d1-0242ac120002")
    __base_url__ = os.getenv('MARCUSLION_API_HOST', "https://uat.marcuslion.com")
    __api_version__ = "core/api/v2"  # no starting slash
    __project_id__ = os.getenv('MARCUSLION_API_PROJECT_ID', "7ea7393b-017d-3ba9-a363-5b7a1043e0fes")
    __backend_api_version__ = "api/v2"
    __backend_base_url__ = __base_url__
    pass


def set_config(env):
    global __base_url__
    global __env__
    global __backend_base_url__
    global __api_version__

    if env == "qa":
        __base_url__ = "https://qa1.marcuslion.com"
        __env__ = env
    elif env == "uat":
        __base_url__ = "https://uat.marcuslion.com"
        __env__ = env
    elif env == "dev":
        __base_url__ = "http://localhost:8384"
        __api_version__ = "api/v2"
        __backend_base_url__ = "http://localhost:8383"
        __env__ = env
    else:
        raise RuntimeError("Invalid environment")
    pass


def get_env():
    global __env__
    return __env__


def get_base_url():
    global __base_url__
    return __base_url__


def get_backend_base_url():
    global __backend_base_url__
    return __backend_base_url__


def get_backend_api_version():
    global __backend_api_version__
    return __backend_api_version__


def get_api_key():
    global __api_key__
    return __api_key__


def get_api_version():
    global __api_version__
    return __api_version__


def get_config():
    global __base_url__
    global __env__
    global __api_key__
    global __api_version__
    global __project_id__

    return {
        "env": __env__,
        "api_key": __api_key__,
        "base_url": __base_url__,
        "project_id": __project_id__,
        "api_version": __api_version__
    }
